@@ -150,6 +150,7 @@ def create_project(projectName):
     # create_pipeline_file(projectName, 'pipeline')
     #
     create_project_config_json()
+    create_server_config_json()
     #
     # create_tester_file(projectName, 'dataset')
     # create_tester_file(projectName, 'reporter')
@@ -361,6 +362,16 @@ def create_project_config_json():
             f.write(data)
             f.close()
 
+def create_server_config_json():
+    with open(os.path.join(__location__, 'cli/cors_allowed_origins.json'), 'r') as file:
+        data = file.read()
+        data = data.replace('generatedDirectory', directories['main'])
+        new_file = directories['server'] + '/cors_allowed_origins.json'
+        if not os.path.exists(new_file):
+            f = open(new_file, "w")
+            f.write(data)
+            f.close()
+
 def to_capitalize_no_underscore(text):
     return ''.join(elem.capitalize() for elem in text.split('_'))
 
