@@ -16,7 +16,7 @@ class generatedClass(ZIDS_Postprocessor):
     def config(self):
         pass
 
-    def normalize_output(self, predictables: List[ZIDS_Predictable]) -> Union[generatedProjectNameOutputs, List[generatedProjectNameOutputs]]:
+    def normalize_output(self, predictables: Union[ZIDS_Predictable, List[ZIDS_Predictable]]) -> Union[generatedProjectNameOutputs, List[generatedProjectNameOutputs]]:
         raise NotImplementedError
         # if predictables:
         #     # return generatedProjectNameOutputs(predictables)
